"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _react = _interopRequireDefault(require("react"));
var _reactNative = require("react-native");
var _flashList = require("@shopify/flash-list");
var _treeView = require("../store/treeView.store");
var _helpers = require("../helpers");
var _CheckboxView = require("./CheckboxView");
var _CustomExpandCollapseIcon = _interopRequireDefault(require("./CustomExpandCollapseIcon"));
var _treeView2 = require("../constants/treeView.constants");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
const NodeList = /*#__PURE__*/_react.default.memo(_NodeList);
var _default = NodeList;
exports.default = _default;
function _NodeList(props) {
  const {
    treeFlashListProps,
    checkBoxViewStyleProps,
    indentationMultiplier,
    CheckboxComponent,
    ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent
  } = props;
  const {
    expanded,
    initialTreeViewData,
    updatedInnerMostChildrenIds,
    searchKeys,
    searchText
  } = (0, _treeView.useTreeViewStore)();
  const [filteredTree, setFilteredTree] = _react.default.useState([]);
  const [flattenedFilteredNodes, setFlattenedFilteredNodes] = _react.default.useState([]);
  _react.default.useEffect(() => {
    const searchTrimmed = searchText.trim().toLowerCase();
    const filterTreeData = _nodes => {
      let filtered = [];
      for (let node of _nodes) {
        if (!searchTrimmed || (0, _helpers.doesNodeContainSearchTerm)(node, searchTrimmed, searchKeys)) {
          // If node itself matches, include it and all its descendants
          filtered.push(node);
        } else if (node.children) {
          // If node does not match, check its children and include them if they match
          const childMatches = filterTreeData(node.children);
          if (childMatches.length > 0) {
            // If any children match, include the node, replacing its children with the matching ones
            filtered.push({
              ...node,
              children: childMatches
            });
          }
        }
      }
      return filtered;
    };
    const tempFilterTree = filterTreeData(initialTreeViewData);
    setFilteredTree(tempFilterTree);
  }, [searchText, searchKeys, initialTreeViewData]);
  _react.default.useEffect(() => {
    const flattenTreeData = function (_nodes) {
      let level = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      let flattened = [];
      for (let node of _nodes) {
        flattened.push({
          ...node,
          level
        });
        if (node.children && expanded.has(node.id)) {
          flattened = [...flattened, ...flattenTreeData(node.children, level + 1)];
        }
      }
      return flattened;
    };
    const tempFlattenTreeData = flattenTreeData(filteredTree);
    setFlattenedFilteredNodes(tempFlattenTreeData);
  }, [filteredTree, expanded]);
  _react.default.useEffect(() => {
    const allLeafIds = [];
    const getLeafNodes = _nodes => {
      for (let node of _nodes) {
        if (node.children) {
          getLeafNodes(node.children);
        } else {
          allLeafIds.push(node.id);
        }
      }
    };
    getLeafNodes(filteredTree);
    updatedInnerMostChildrenIds(allLeafIds);
  }, [filteredTree, updatedInnerMostChildrenIds]);
  const nodeRenderer = _react.default.useCallback(_ref => {
    let {
      item
    } = _ref;
    return /*#__PURE__*/_react.default.createElement(Node, {
      node: item,
      level: item.level || 0,
      checkBoxViewStyleProps: checkBoxViewStyleProps,
      indentationMultiplier: indentationMultiplier,
      CheckboxComponent: CheckboxComponent,
      ExpandCollapseIconComponent: ExpandCollapseIconComponent,
      ExpandCollapseTouchableComponent: ExpandCollapseTouchableComponent
    });
  }, [CheckboxComponent, ExpandCollapseIconComponent, ExpandCollapseTouchableComponent, checkBoxViewStyleProps, indentationMultiplier]);
  return /*#__PURE__*/_react.default.createElement(_flashList.FlashList, _extends({
    estimatedItemSize: 36,
    removeClippedSubviews: true,
    keyboardShouldPersistTaps: "handled",
    drawDistance: 50,
    data: flattenedFilteredNodes,
    renderItem: nodeRenderer,
    ListHeaderComponent: /*#__PURE__*/_react.default.createElement(HeaderFooterView, null),
    ListFooterComponent: /*#__PURE__*/_react.default.createElement(HeaderFooterView, null)
  }, treeFlashListProps));
}
;
function HeaderFooterView() {
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.defaultHeaderFooter
  });
}
function getValue(isChecked, isIndeterminate) {
  if (isIndeterminate) {
    return 'indeterminate';
  } else if (isChecked) {
    return true;
  } else {
    return false;
  }
}
const Node = /*#__PURE__*/_react.default.memo(_Node);
function _Node(props) {
  var _node$children;
  const {
    node,
    level,
    checkBoxViewStyleProps,
    indentationMultiplier = _treeView2.defaultIndentationMultiplier,
    ExpandCollapseIconComponent = _CustomExpandCollapseIcon.default,
    CheckboxComponent = _CheckboxView.CheckboxView,
    ExpandCollapseTouchableComponent = _reactNative.TouchableOpacity
  } = props;
  const {
    expanded,
    checked,
    indeterminate
  } = (0, _treeView.useTreeViewStore)();
  const isChecked = checked.has(node.id);
  const isIndeterminate = indeterminate.has(node.id);
  const isExpanded = expanded.has(node.id);
  const [value, setValue] = _react.default.useState(getValue(isChecked, isIndeterminate));
  _react.default.useEffect(() => {
    setValue(getValue(isChecked, isIndeterminate));
  }, [isChecked, isIndeterminate]);
  const _onToggleExpand = _react.default.useCallback(() => {
    (0, _helpers.handleToggleExpand)(node.id);
  }, [node.id]);
  const _onCheck = _react.default.useCallback(() => {
    (0, _helpers.toggleCheckboxes)([node.id]);
  }, [node.id]);
  return /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: [styles.nodeParentView, {
      marginStart: level * indentationMultiplier
    }]
  }, /*#__PURE__*/_react.default.createElement(_reactNative.View, {
    style: styles.nodeCheckboxAndArrowRow
  }, /*#__PURE__*/_react.default.createElement(CheckboxComponent, _extends({
    text: node.name,
    onValueChange: _onCheck,
    value: value
  }, checkBoxViewStyleProps)), (_node$children = node.children) !== null && _node$children !== void 0 && _node$children.length ? /*#__PURE__*/_react.default.createElement(ExpandCollapseTouchableComponent, {
    style: styles.nodeExpandableArrowTouchable,
    onPress: _onToggleExpand
  }, /*#__PURE__*/_react.default.createElement(ExpandCollapseIconComponent, {
    isExpanded: isExpanded
  })) : null));
}
;
const styles = _reactNative.StyleSheet.create({
  defaultHeaderFooter: {
    padding: 5
  },
  nodeParentView: {
    flex: 1
  },
  nodeExpandableArrowTouchable: {
    flex: 1
  },
  nodeCheckboxAndArrowRow: {
    flexDirection: 'row',
    alignItems: 'center',
    minWidth: "100%"
  }
});
//# sourceMappingURL=NodeList.js.map