function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from "react";
import { View, StyleSheet, TouchableOpacity } from "react-native";
import { FlashList } from "@shopify/flash-list";
import { useTreeViewStore } from "../store/treeView.store";
import { doesNodeContainSearchTerm, handleToggleExpand, toggleCheckboxes } from "../helpers";
import { CheckboxView } from "./CheckboxView";
import CustomExpandCollapseIcon from "./CustomExpandCollapseIcon";
import { defaultIndentationMultiplier } from "../constants/treeView.constants";
const NodeList = /*#__PURE__*/React.memo(_NodeList);
export default NodeList;
function _NodeList(props) {
  const {
    treeFlashListProps,
    checkBoxViewStyleProps,
    indentationMultiplier,
    CheckboxComponent,
    ExpandCollapseIconComponent,
    ExpandCollapseTouchableComponent
  } = props;
  const {
    expanded,
    initialTreeViewData,
    updatedInnerMostChildrenIds,
    searchKeys,
    searchText
  } = useTreeViewStore();
  const [filteredTree, setFilteredTree] = React.useState([]);
  const [flattenedFilteredNodes, setFlattenedFilteredNodes] = React.useState([]);
  React.useEffect(() => {
    const searchTrimmed = searchText.trim().toLowerCase();
    const filterTreeData = _nodes => {
      let filtered = [];
      for (let node of _nodes) {
        if (!searchTrimmed || doesNodeContainSearchTerm(node, searchTrimmed, searchKeys)) {
          // If node itself matches, include it and all its descendants
          filtered.push(node);
        } else if (node.children) {
          // If node does not match, check its children and include them if they match
          const childMatches = filterTreeData(node.children);
          if (childMatches.length > 0) {
            // If any children match, include the node, replacing its children with the matching ones
            filtered.push({
              ...node,
              children: childMatches
            });
          }
        }
      }
      return filtered;
    };
    const tempFilterTree = filterTreeData(initialTreeViewData);
    setFilteredTree(tempFilterTree);
  }, [searchText, searchKeys, initialTreeViewData]);
  React.useEffect(() => {
    const flattenTreeData = function (_nodes) {
      let level = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
      let flattened = [];
      for (let node of _nodes) {
        flattened.push({
          ...node,
          level
        });
        if (node.children && expanded.has(node.id)) {
          flattened = [...flattened, ...flattenTreeData(node.children, level + 1)];
        }
      }
      return flattened;
    };
    const tempFlattenTreeData = flattenTreeData(filteredTree);
    setFlattenedFilteredNodes(tempFlattenTreeData);
  }, [filteredTree, expanded]);
  React.useEffect(() => {
    const allLeafIds = [];
    const getLeafNodes = _nodes => {
      for (let node of _nodes) {
        if (node.children) {
          getLeafNodes(node.children);
        } else {
          allLeafIds.push(node.id);
        }
      }
    };
    getLeafNodes(filteredTree);
    updatedInnerMostChildrenIds(allLeafIds);
  }, [filteredTree, updatedInnerMostChildrenIds]);
  const nodeRenderer = React.useCallback(_ref => {
    let {
      item
    } = _ref;
    return /*#__PURE__*/React.createElement(Node, {
      node: item,
      level: item.level || 0,
      checkBoxViewStyleProps: checkBoxViewStyleProps,
      indentationMultiplier: indentationMultiplier,
      CheckboxComponent: CheckboxComponent,
      ExpandCollapseIconComponent: ExpandCollapseIconComponent,
      ExpandCollapseTouchableComponent: ExpandCollapseTouchableComponent
    });
  }, [CheckboxComponent, ExpandCollapseIconComponent, ExpandCollapseTouchableComponent, checkBoxViewStyleProps, indentationMultiplier]);
  return /*#__PURE__*/React.createElement(FlashList, _extends({
    estimatedItemSize: 36,
    removeClippedSubviews: true,
    keyboardShouldPersistTaps: "handled",
    drawDistance: 50,
    data: flattenedFilteredNodes,
    renderItem: nodeRenderer,
    ListHeaderComponent: /*#__PURE__*/React.createElement(HeaderFooterView, null),
    ListFooterComponent: /*#__PURE__*/React.createElement(HeaderFooterView, null)
  }, treeFlashListProps));
}
;
function HeaderFooterView() {
  return /*#__PURE__*/React.createElement(View, {
    style: styles.defaultHeaderFooter
  });
}
function getValue(isChecked, isIndeterminate) {
  if (isIndeterminate) {
    return 'indeterminate';
  } else if (isChecked) {
    return true;
  } else {
    return false;
  }
}
const Node = /*#__PURE__*/React.memo(_Node);
function _Node(props) {
  var _node$children;
  const {
    node,
    level,
    checkBoxViewStyleProps,
    indentationMultiplier = defaultIndentationMultiplier,
    ExpandCollapseIconComponent = CustomExpandCollapseIcon,
    CheckboxComponent = CheckboxView,
    ExpandCollapseTouchableComponent = TouchableOpacity
  } = props;
  const {
    expanded,
    checked,
    indeterminate
  } = useTreeViewStore();
  const isChecked = checked.has(node.id);
  const isIndeterminate = indeterminate.has(node.id);
  const isExpanded = expanded.has(node.id);
  const [value, setValue] = React.useState(getValue(isChecked, isIndeterminate));
  React.useEffect(() => {
    setValue(getValue(isChecked, isIndeterminate));
  }, [isChecked, isIndeterminate]);
  const _onToggleExpand = React.useCallback(() => {
    handleToggleExpand(node.id);
  }, [node.id]);
  const _onCheck = React.useCallback(() => {
    toggleCheckboxes([node.id]);
  }, [node.id]);
  return /*#__PURE__*/React.createElement(View, {
    style: [styles.nodeParentView, {
      marginStart: level * indentationMultiplier
    }]
  }, /*#__PURE__*/React.createElement(View, {
    style: styles.nodeCheckboxAndArrowRow
  }, /*#__PURE__*/React.createElement(CheckboxComponent, _extends({
    text: node.name,
    onValueChange: _onCheck,
    value: value
  }, checkBoxViewStyleProps)), (_node$children = node.children) !== null && _node$children !== void 0 && _node$children.length ? /*#__PURE__*/React.createElement(ExpandCollapseTouchableComponent, {
    style: styles.nodeExpandableArrowTouchable,
    onPress: _onToggleExpand
  }, /*#__PURE__*/React.createElement(ExpandCollapseIconComponent, {
    isExpanded: isExpanded
  })) : null));
}
;
const styles = StyleSheet.create({
  defaultHeaderFooter: {
    padding: 5
  },
  nodeParentView: {
    flex: 1
  },
  nodeExpandableArrowTouchable: {
    flex: 1
  },
  nodeCheckboxAndArrowRow: {
    flexDirection: 'row',
    alignItems: 'center',
    minWidth: "100%"
  }
});
//# sourceMappingURL=NodeList.js.map